from django.shortcuts import render

class ReadOnlySiteMiddleware(object):
    
    def process_request(self, request):

        """
        If we are in read-only mode, figure out whether or not to render the request.
        We read in settings at the last possible minute sure that any dynamic
        settings are honored (eg django-dbsettings or similar)
        """
        
        from django.conf import settings

        readonly = getattr(settings, 'SITE_READ_ONLY', False)
        
        if not readonly:
            # Shortcut out if we aren't in read-only mode
            return None

        
        exempt_path_starts = getattr(settings, 'READ_ONLY_EXEMPT_PATH_STARTS', [])
        exempt_paths = getattr(settings, 'READ_ONLY_EXEMPT_PATHS', [])
        blacklist_path_starts = getattr(settings, 'READ_ONLY_PATH_STARTS', [])
        blacklist_paths = getattr(settings, 'READ_ONLY_PATHS', [])
        template = getattr(settings, 'READ_ONLY_TEMPLATE', None)


        if request.method <> 'GET':
            # Shortcut - will skip rest of this if statement
            # and just render the 'read only' template.
            pass

        elif exempt_path_starts or exempt_paths:
            # Deal with whitelisted items
            for path in exempt_path_starts:
                if request.path.startswith(path):
                    return None
        
            if request.path in exempt_paths:
                return None
        else:
            # Deal with blacklist
            is_blacklisted = False

            if request.path in blacklist_paths:
                is_blacklisted = True

            for path in blacklist_path_starts:
                if request.path.startswith(path):
                    is_blacklisted = True
            
            if not is_blacklisted:
                return None

        return render(request, [template, 'readonly/readonly.html'])




import os
import sys
from distutils.util import convert_path
from fnmatch import fnmatchcase
from setuptools import setup, find_packages

version = '0.1.2'

# Provided as an attribute, so you can append to these instead
# of replicating them:
standard_exclude = ('*.py', '*.pyc', '*$py.class', '*~', '.*', '*.bak')
standard_exclude_directories = ('.*', 'CVS', '_darcs', './build',
                                './dist', 'EGG-INFO', '*.egg-info')

# (c) 2005 Ian Bicking and contributors; written for Paste (http://pythonpaste.org)
# Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
# Note: you may want to copy this into your setup.py file verbatim, as
# you can't import this from another package, when you don't know if
# that package is installed yet.
def find_package_data(
    where='.', package='',
    exclude=standard_exclude,
    exclude_directories=standard_exclude_directories,
    only_in_packages=True,
    show_ignored=False):
    """
    Return a dictionary suitable for use in ``package_data``
    in a distutils ``setup.py`` file.

    The dictionary looks like::

        {'package': [files]}

    Where ``files`` is a list of all the files in that package that
    don't match anything in ``exclude``.

    If ``only_in_packages`` is true, then top-level directories that
    are not packages won't be included (but directories under packages
    will).

    Directories matching any pattern in ``exclude_directories`` will
    be ignored; by default directories with leading ``.``, ``CVS``,
    and ``_darcs`` will be ignored.

    If ``show_ignored`` is true, then all the files that aren't
    included in package data are shown on stderr (for debugging
    purposes).

    Note patterns use wildcards, or can be exact paths (including
    leading ``./``), and all searching is case-insensitive.
    """

    out = {}
    stack = [(convert_path(where), '', package, only_in_packages)]
    while stack:
        where, prefix, package, only_in_packages = stack.pop(0)
        for name in os.listdir(where):
            fn = os.path.join(where, name)
            if os.path.isdir(fn):
                bad_name = False
                for pattern in exclude_directories:
                    if (fnmatchcase(name, pattern)
                        or fn.lower() == pattern.lower()):
                        bad_name = True
                        if show_ignored:
                            print >> sys.stderr, (
                                "Directory %s ignored by pattern %s"
                                % (fn, pattern))
                        break
                if bad_name:
                    continue
                if (os.path.isfile(os.path.join(fn, '__init__.py'))
                    and not prefix):
                    if not package:
                        new_package = name
                    else:
                        new_package = package + '.' + name
                    stack.append((fn, '', new_package, False))
                else:
                    stack.append((fn, prefix + name + '/', package, only_in_packages))
            elif package or not only_in_packages:
                # is a file
                bad_name = False
                for pattern in exclude:
                    if (fnmatchcase(name, pattern)
                        or fn.lower() == pattern.lower()):
                        bad_name = True
                        if show_ignored:
                            print >> sys.stderr, (
                                "File %s ignored by pattern %s"
                                % (fn, pattern))
                        break
                if bad_name:
                    continue
                out.setdefault(package, []).append(prefix+name)
    return out



LONG_DESCRIPTION = """
====================
django-readonly-site
====================
Take parts of your Django website offline by changing settings.SITE_READ_ONLY = True.
"""

setup(
    name='django-readonly-site',
    version=version,
    description="Middleware to take your Django website offline by changing settings.SITE_READ_ONLY",
    long_description=LONG_DESCRIPTION,
    classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Framework :: Django",
        "Environment :: Web Environment",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: BSD License",
        "Natural Language :: English",
        "Intended Audience :: Developers",
        "Development Status :: 3 - Alpha",
    ],
    keywords=['django',],
    author='Ross Poulton',
    author_email='ross@rossp.org',
    url='http://github.com/rossp/django-readonly-site',
    license='BSD',
    packages=find_packages(),
    package_data=find_package_data("readonly", only_in_packages=False),
    include_package_data=True,
    zip_safe=False,
    install_requires=['setuptools'],
)

